package com.datacloudsec.utils;

import com.datacloudsec.exception.UEException;
import com.jcraft.jsch.ChannelSftp;
import com.jcraft.jsch.JSch;
import com.jcraft.jsch.JSchException;
import com.jcraft.jsch.Session;
import com.jcraft.jsch.SftpException;
import com.jcraft.jsch.SftpProgressMonitor;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.text.DecimalFormat;
import java.util.Properties;
import org.apache.commons.io.IOUtils;
import org.apache.log4j.Logger;

public class SftpDownloader {

   private static long minimum = 0L;
   private static long maximum = 100L;
   private static final Logger logger = Logger.getLogger(SftpDownloader.class);


   public static void download(String username, String password, String host, Integer port, String localPath, final String remotePath) throws Exception {
      JSch jsch = new JSch();
      Session session = null;
      ChannelSftp channel = null;
      BufferedOutputStream outs = null;

      try {
         session = jsch.getSession(username, host, port == null?22:port.intValue());
         session.setPassword(password);
         Properties e = new Properties();
         e.put("StrictHostKeyChecking", "no");
         session.setConfig(e);
         session.connect(5000);
         channel = (ChannelSftp)session.openChannel("sftp");
         channel.connect(5000);
         channel.setFilenameEncoding("UTF-8");
         outs = new BufferedOutputStream(new FileOutputStream(new File(localPath)));
         channel.get(remotePath, outs, new SftpProgressMonitor() {

            private long current = 0L;

            public void init(int op, String src, String dest, long max) {
               SftpDownloader.minimum = 0L;
               SftpDownloader.maximum = max;
            }
            public void end() {
               if(SftpDownloader.logger.isInfoEnabled()) {
                  SftpDownloader.logger.debug(String.format("download file:%s complete", new Object[]{remotePath}));
               }

            }
            public boolean count(long count) {
               this.current += count;
               SftpDownloader.show(this.current);
               return true;
            }
         });
      } catch (JSchException var16) {
         logger.error(String.format("连接远程主机%s:%d发生错误", new Object[]{host, Integer.valueOf(port == null?22:port.intValue())}), var16);
         throw new UEException(String.format("连接远程主机%s:%d发生错误", new Object[]{host, Integer.valueOf(port == null?22:port.intValue())}), var16);
      } catch (SftpException var17) {
         logger.error(String.format("获取远程文件：%s发生错误", new Object[]{remotePath}), var17);
         throw new UEException(String.format("获取远程文件：%s发生错误", new Object[]{remotePath}), var17);
      } catch (FileNotFoundException var18) {
         logger.error(String.format("无法找到本地文件：%s", new Object[]{localPath}), var18);
         throw new UEException(String.format("无法找到本地文件：%s", new Object[]{localPath}), var18);
      } finally {
         IOUtils.closeQuietly(outs);
         if(channel != null) {
            channel.disconnect();
            channel.quit();
         }

         if(session != null) {
            session.disconnect();
         }

      }

   }

   public static float show(long value) {
      if(value >= minimum && value <= maximum) {
         minimum = value;
         float rate = (float)((double)minimum * 1.0D / (double)maximum);
         System.out.print((new DecimalFormat("#.##%")).format((double)rate) + " -> ");
         return rate;
      } else {
         return 0.0F;
      }
   }

   public static void main(String[] args) throws Exception {
      download("root", "rtfkqkhh", "192.168.0.213", Integer.valueOf(22), "/root/user.MYD", "/data/mysql/mysql/user.MYD");
      System.out.println("\n下载完成！");
   }
}
